@@ -1,9 +1,10 @@
-import requests
 from unittest import TestCase
 from unittest.mock import patch
 
-from . import BackendTestMixin
+import requests
+
 from embed_video.backends import SoundCloudBackend, VideoDoesntExistException
+from embed_video.tests.backends import BackendTestMixin
 
 
 class SoundCloudBackendTestCase(BackendTestMixin, TestCase):
